OGBBioKG
========

.. currentmodule:: pykeen.datasets

.. autoclass:: OGBBioKG
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~OGBBioKG.name

   .. rubric:: Attributes Documentation

   .. autoattribute:: name
